@@ -926,6 +926,18 @@
         get number_of_views() {
             return this.views.length + this.view_to_load.length;
         },
+        get view_index() {
+            return this.views.indexOf(this.current_view);
+        },
+        get next_view_type() {
+            var views = this.views.concat(this.view_to_load)
+            var next_view_index = (this.view_index + 1) % views.length;
+            var next_view = views[next_view_index];
+            if (typeof next_view != 'string') {
+                next_view = next_view.view_type;
+            }
+            return next_view;
+        },
         switch_view: function(
             view_type=null, view_id=null, creatable=null, display=true) {
             if (view_id !== null) {
@@ -1589,7 +1601,6 @@
         },
         save_current: function() {
             var current_record = this.current_record;
-            let new_record = current_record.id < 0;
             if (!current_record) {
                 if (this.current_view &&
                     (this.current_view.view_type == 'tree') &&
@@ -1600,6 +1611,7 @@
                     return jQuery.when();
                 }
             }
+            let new_record = current_record.id < 0;
             if (this.current_view) {
                 this.current_view.set_value();
                 var fields = this.current_view.get_fields();
@@ -2275,7 +2287,8 @@
                     return view.display(selected_nodes);
                 } else {
                     var record;
-                    if (!jQuery.isEmptyObject(selected_nodes)) {
+                    if (!jQuery.isEmptyObject(selected_nodes) &&
+                        !this.current_record) {
                         for (const id of selected_nodes[0]) {
                             const new_record = this.group.get(id);
                             if (!new_record) {
