@@ -1452,6 +1452,7 @@
                 }
             }
             const view_type = this.screen.current_view.view_type;
+            var next_view_type = this.screen.next_view_type;
             const has_views = this.screen.number_of_views > 1;
             var buttons = ['print', 'relate', 'email', 'attach'];
             for (const button_id of buttons) {
@@ -1472,7 +1473,9 @@
                 set_sensitive(button_id, position && can_be_sensitive);
             }
             set_sensitive(
-                'switch_', (position || (view_type == 'form')) && has_views);
+                'switch_',
+                (position || (view_type == 'form') || (next_view_type != 'form')) &&
+                has_views);
             set_sensitive('delete_', this.screen.deletable);
             set_sensitive('previous', this.screen.has_previous());
             set_sensitive('next', this.screen.has_next());
