@@ -3,11 +3,49 @@
 (function() {
     'use strict';
 
+    function set_calendar_height(el) {
+        var height = window.innerHeight - 15;
+        if (el.parents('.modal-body').length) {
+            var modal_height = parseInt(
+                el.parents('.modal-body').css('max-height'), 10);
+            if (isNaN(modal_height)) {
+                height -= 200;
+            } else {
+                height = modal_height;
+            }
+        }
+        height -= el.find('.fc-toolbar').height();
+        el.parents('.panel-body').each(function(i, panel) {
+            panel = jQuery(panel);
+            height -= parseInt(panel.css('padding-top'), 10);
+            height -= parseInt(panel.css('padding-bottom'), 10);
+        });
+        el.parents('.panel').each(function(i, panel) {
+            panel = jQuery(panel);
+            var lengths = panel.css('box-shadow').match(/\d+px/g);
+            if (lengths && lengths.length) {
+                lengths = lengths.map(function(length) {
+                    length = parseInt(length, 10);
+                    return isNaN(length) ? 0 : length;
+                });
+                height -= Math.max.apply(null, lengths);
+            }
+        });
+        height -= el[0].getBoundingClientRect().y;
+        el.fullCalendar('option', 'contentHeight', height);
+    }
+
+    jQuery(window).resize(function() {
+        jQuery('.calendar').each(function(i, el) {
+            set_calendar_height(jQuery(el));
+        });
+    });
+
     Sao.View.CalendarXMLViewParser = Sao.class_(Sao.View.XMLViewParser, {
         _parse_calendar: function(node, attributes) {
-            [].forEach.call(node.childNodes, function(child) {
+            for (const child of node.childNodes) {
                 this.parse(child);
-            }.bind(this));
+            }
 
             var view_week;
             if (this.view.screen.model.fields[attributes.dtstart]
@@ -45,8 +83,10 @@
                 defaultView: defaultview,
                 header: header,
                 timeFormat: 'H:mm',
+                scrollTime: (
+                    this.view.screen.context.calendar_scroll_time ||
+                    Sao.Time(6)).toString(),
                 events: this.view.get_events.bind(this.view),
-                contentHeight: 'auto',
                 locale: Sao.i18n.getlang().slice(0, 2),
                 isRTL: Sao.i18n.rtl,
                 themeSystem: 'bootstrap3',
@@ -83,6 +123,7 @@
     /* Fullcalendar works with utc date, the default week start day depends on
        the user language, the events dates are handled by moment object. */
         editable: false,
+        creatable: false,
         view_type: 'calendar',
         xml_parser: Sao.View.CalendarXMLViewParser,
         init: function(view_id, screen, xml) {
@@ -111,13 +152,16 @@
         },
         display: function() {
             this.el.fullCalendar('render');
+            set_calendar_height(this.el);
             // Don't refetch events from server when get_events is processing
             if (!this.processing) {
                 this.el.fullCalendar('refetchEvents');
             }
         },
         insert_event: function(record) {
-            var title = this.screen.model.fields[this.fields[0]].get_client(
+            var description_fields = jQuery.extend([], this.fields);
+            var title_field = description_fields.shift();
+            var title = this.screen.model.fields[title_field].get_client(
                 record);
             var field_start = record.model.fields[this.attributes.dtstart];
             var date_start = field_start.get_client(record);
@@ -137,10 +181,9 @@
                 model_access.write);
 
             var description = [];
-            for (var i = 1; i < this.fields.length; i++) {
+            for (const field of description_fields) {
                 description.push(
-                    this.screen.model.fields[this.fields[i]].get_client(
-                        record));
+                    this.screen.model.fields[field].get_client( record));
             }
             description = description.join('\n');
             if (date_start) {
@@ -187,24 +230,24 @@
             }
             this.events =  [];
             var promisses = [];
-            prm.then(function()  {
-                this.group.forEach(function(record) {
+            prm.then(() => {
+                this.group.forEach(record => {
                     var record_promisses = [];
-                    this.fields.forEach(function(name) {
+                    for (const name of this.fields) {
                         record_promisses.push(record.load(name));
-                    });
+                    }
                     var prm = jQuery.when.apply(jQuery, record_promisses).then(
-                        function(){
+                        () => {
                             this.insert_event(record);
-                        }.bind(this));
+                        });
                     promisses.push(prm);
-                }.bind(this));
-                return jQuery.when.apply(jQuery, promisses).then(function() {
+                });
+                return jQuery.when.apply(jQuery, promisses).then(() => {
                     callback(this.events);
-                }.bind(this)).always(function() {
+                }).always(() => {
                     this.processing = false;
-                }.bind(this));
-            }.bind(this));
+                });
+            });
         },
         event_click: function(calEvent, jsEvent, view) {
             // Prevent opening the wrong event while the calendar event clicked
@@ -212,9 +255,9 @@
             if (!this.clicked_event) {
                 this.clicked_event = true;
                 this.screen.current_record = calEvent.record;
-                this.screen.switch_view().always(function(){
+                this.screen.switch_view().always(() => {
                     this.clicked_event = false;
-                }.bind(this));
+                });
             }
         },
         event_drop: function(event, delta, revertFunc, jsEvent, ui, view) {
@@ -343,7 +386,10 @@
         },
         get_selected_date: function(){
             return this.el.fullCalendar('getDate');
-        }
+        },
+        get listed_records() {
+            return this.events.map(e => e.record);
+        },
     });
 
 }());
