@@ -4,7 +4,6 @@
     'use strict';
 
     Sao.View.ListGroupViewForm = Sao.class_(Sao.View.Form, {
-        editable: true,
         get record() {
             return this._record;
         },
@@ -19,10 +18,14 @@
     });
 
     Sao.View.ListForm = Sao.class_(Sao.View, {
+        editable: true,
+        creatable: true,
         view_type: 'list-form',
         init: function(view_id, screen, xml) {
             Sao.View.ListForm._super.init.call(this, view_id, screen, xml);
-            this.editable = true;
+            if (this.attributes.creatable) {
+                this.creatable = Boolean(parseInt(this.attributes.creatable, 10));
+            }
 
             this.form_xml = xml;
             this.el = jQuery('<ul/>', {
@@ -30,10 +33,16 @@
             });
             this._view_forms = [];
         },
-        display: function() {
+        display: function(selected_nodes) {
             var record, view_form, view_form_frame, to_delete;
             var deferreds = [];
             var new_elements = [];
+            var selected = new Set();
+            if (!jQuery.isEmptyObject(selected_nodes)) {
+                for (const id_path of selected_nodes) {
+                    selected.add(id_path[0]);
+                }
+            }
             for (var i = 0; i < this.group.length; i++) {
                 record = this.group[i];
                 view_form = this._view_forms[i];
@@ -52,7 +61,7 @@
                 } else {
                     view_form_frame.removeClass('disabled');
                 }
-                if (this.record === record) {
+                if ((this.record === record) || selected.has(record.id)) {
                     view_form_frame.addClass('list-group-item-selected');
                 } else {
                     view_form_frame.removeClass('list-group-item-selected');
@@ -67,6 +76,17 @@
                 .parent().detach();
             return jQuery.when.apply(jQuery, deferreds);
         },
+        get_selected_paths: function() {
+            var paths = [];
+            var view_form_frame;
+            for (const form of this._view_forms) {
+                view_form_frame = form.el.parent();
+                if (view_form_frame.hasClass('list-group-item-selected')) {
+                    paths.push([form.record.id]);
+                }
+            }
+            return paths;
+        },
         _create_form: function(record) {
             var view_form = new Sao.View.ListGroupViewForm(
                 this.view_id, this.screen, this.form_xml);
@@ -81,17 +101,18 @@
             return frame;
         },
         get selected_records() {
-            var view_form, records = [];
-            var frame;
-            for (var i = 0; i < this._view_forms.length; i++) {
-                view_form = this._view_forms[i];
-                frame = view_form.el.parent();
+            var records = [];
+            for (const view_form of this._view_forms) {
+                const frame = view_form.el.parent();
                 if (frame.hasClass('list-group-item-selected')) {
                     records.push(view_form.record);
                 }
             }
             return records;
         },
+        get listed_records() {
+            return this.group.slice();
+        },
         set_cursor: function(new_, reset_view) {
             if (new_) {
                 this.el.animate({
@@ -118,34 +139,53 @@
                 to = tmp;
             }
 
-            var select_form = function(form) {
+            for (const form of this._view_forms.slice(from, to + 1)) {
                 form.el.parent().addClass('list-group-item-selected');
-            };
-            this._view_forms.slice(from, to + 1).forEach(select_form);
+            }
         },
         _select_row: function(event_) {
-            var current_view_form;
-            var view_form_idx = event_.data;
-            var view_form = this._view_forms[view_form_idx];
+            var next_form_idx = event_.data;
+            var next_view_form = this._view_forms[next_form_idx];
 
-            if (event_.shiftKey) {
-                for (var i=0; i < this._view_forms.length; i++) {
-                    if (this._view_forms[i].record === this.record) {
-                        current_view_form = this._view_forms[i];
-                        break;
+            var prm = jQuery.when();
+            if (this.record && (next_view_form.record != this.record)) {
+                if (!this.screen.group.parent) {
+                    if (!this.record.validate(
+                            this.get_fields(), false, false, false)) {
+                        prm = jQuery.Deferred().reject();
+                    } else {
+                        prm = this.record.save();
                     }
+                } else if (this.screen.attributes.pre_validate) {
+                    prm = this.record.pre_validate();
                 }
-                this.select_records(i, view_form_idx);
-            } else {
-                if (!(event_.ctrlKey || event_.metaKey)) {
-                    this.select_records(null, null);
+            }
+
+            prm.done(() => {
+                var current_view_form;
+
+                if (event_.shiftKey) {
+                    let i = 0;
+                    for (const other_view_form of this._view_forms) {
+                        if (other_view_form.record === this.record) {
+                            current_view_form = other_view_form;
+                            break;
+                        }
+                        i++;
+                    }
+                    this.select_records(i, next_form_idx);
+                } else {
+                    if (!(event_.ctrlKey || event_.metaKey)) {
+                        this.select_records(null, null);
+                    }
+                    this.record = next_view_form.record;
+                    next_view_form.el.parent()
+                        .toggleClass('list-group-item-selected');
                 }
-                this.record = view_form.record;
-                view_form.el.parent().toggleClass('list-group-item-selected');
-            }
-            if (current_view_form) {
-                this.record = current_view_form.record;
-            }
+                if (current_view_form) {
+                    this.record = current_view_form.record;
+                }
+            });
         }
     });
 
